# Divinepy
> A collection of tools to work with LRO Diviner data.


## Install

`pip install divinepy`

## How to use

The provided tools are based primarily on publicly available LRO Diviner and related support data (like lunar digital elevation data).
